@@ -1,4 +1,4 @@
-# FIAIF is an Intelligent firewall, version: $Revision: 1.14 $
+# FIAIF is an Intelligent firewall, version: $Revision: 1.1 $
 #
 # description: Automates a packet filtering firewall with iptables.
 #
@@ -61,9 +61,6 @@ function add_sanity_check()
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN,ACK -m state --state NEW,RELATED -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,ACK -m state --state ESTABLISHED -j RETURN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,ACK -m state --state NEW,RELATED -j LOG_SCAN_NOLOG
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST,ACK -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST,ACK -m state --state NEW -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST,ACK -m state --state RELATED -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,PSH,RST -m state --state ESTABLISHED -j RETURN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,PSH,RST -m state --state NEW,RELATED -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,PSH,ACK -m state --state ESTABLISHED -j RETURN
