@@ -653,7 +653,7 @@ function configure_zone ()
     # Allow server to answer DHCP queries.
     debug_out "DHCP_SERVER=${DHCP_SERVER}"
     if (( DHCP_SERVER == 1 )); then 
-	IPTABLES -A DEV_${DEV}_SRC -p UDP -s 0.0.0.0 -d 255.255.255.255 \
+	IPTABLES -A DEV_${DEV}_SRC -p UDP -d 255.255.255.255 \
 	    --dport bootps -j LOG_ACCEPT
 	IPTABLES -A DEV_${DEV}_DST -p UDP -d 255.255.255.255 \
 	    --dport bootpc -j LOG_ACCEPT 
@@ -664,7 +664,7 @@ function configure_zone ()
     if (( DYNAMIC == 1 )); then 
 	IPTABLES -A DEV_${DEV}_SRC -p UDP -d 255.255.255.255 \
 	    --dport bootpc -j LOG_ACCEPT
-	IPTABLES -A DEV_${DEV}_DST -p UDP -d 255.255.255.255 -s 0.0.0.0 \
+	IPTABLES -A DEV_${DEV}_DST -p UDP -d 255.255.255.255 \
 	    --dport bootps -j LOG_ACCEPT 
     fi
  
